# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetWarehousesDefaultWarehouseOverridesResult',
    'AwaitableGetWarehousesDefaultWarehouseOverridesResult',
    'get_warehouses_default_warehouse_overrides',
    'get_warehouses_default_warehouse_overrides_output',
]

@pulumi.output_type
class GetWarehousesDefaultWarehouseOverridesResult:
    """
    A collection of values returned by getWarehousesDefaultWarehouseOverrides.
    """
    def __init__(__self__, default_warehouse_overrides=None, id=None, page_size=None):
        if default_warehouse_overrides and not isinstance(default_warehouse_overrides, list):
            raise TypeError("Expected argument 'default_warehouse_overrides' to be a list")
        pulumi.set(__self__, "default_warehouse_overrides", default_warehouse_overrides)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)

    @_builtins.property
    @pulumi.getter(name="defaultWarehouseOverrides")
    def default_warehouse_overrides(self) -> Sequence['outputs.GetWarehousesDefaultWarehouseOverridesDefaultWarehouseOverrideResult']:
        return pulumi.get(self, "default_warehouse_overrides")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")


class AwaitableGetWarehousesDefaultWarehouseOverridesResult(GetWarehousesDefaultWarehouseOverridesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWarehousesDefaultWarehouseOverridesResult(
            default_warehouse_overrides=self.default_warehouse_overrides,
            id=self.id,
            page_size=self.page_size)


def get_warehouses_default_warehouse_overrides(page_size: Optional[_builtins.int] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWarehousesDefaultWarehouseOverridesResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to list all default warehouse overrides in the workspace.

    > **Note** This data source requires workspace admin permissions.

    ## Example Usage


    :param _builtins.int page_size: The maximum number of overrides to return. The service may return fewer than
           this value.
           If unspecified, at most 100 overrides will be returned.
           The maximum value is 1000; values above 1000 will be coerced to 1000
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getWarehousesDefaultWarehouseOverrides:getWarehousesDefaultWarehouseOverrides', __args__, opts=opts, typ=GetWarehousesDefaultWarehouseOverridesResult).value

    return AwaitableGetWarehousesDefaultWarehouseOverridesResult(
        default_warehouse_overrides=pulumi.get(__ret__, 'default_warehouse_overrides'),
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'))
def get_warehouses_default_warehouse_overrides_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWarehousesDefaultWarehouseOverridesResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to list all default warehouse overrides in the workspace.

    > **Note** This data source requires workspace admin permissions.

    ## Example Usage


    :param _builtins.int page_size: The maximum number of overrides to return. The service may return fewer than
           this value.
           If unspecified, at most 100 overrides will be returned.
           The maximum value is 1000; values above 1000 will be coerced to 1000
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getWarehousesDefaultWarehouseOverrides:getWarehousesDefaultWarehouseOverrides', __args__, opts=opts, typ=GetWarehousesDefaultWarehouseOverridesResult)
    return __ret__.apply(lambda __response__: GetWarehousesDefaultWarehouseOverridesResult(
        default_warehouse_overrides=pulumi.get(__response__, 'default_warehouse_overrides'),
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size')))
