# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeatureEngineeringMaterializedFeatureResult',
    'AwaitableGetFeatureEngineeringMaterializedFeatureResult',
    'get_feature_engineering_materialized_feature',
    'get_feature_engineering_materialized_feature_output',
]

@pulumi.output_type
class GetFeatureEngineeringMaterializedFeatureResult:
    """
    A collection of values returned by getFeatureEngineeringMaterializedFeature.
    """
    def __init__(__self__, cron_schedule=None, feature_name=None, id=None, last_materialization_time=None, materialized_feature_id=None, offline_store_config=None, online_store_config=None, pipeline_schedule_state=None, table_name=None):
        if cron_schedule and not isinstance(cron_schedule, str):
            raise TypeError("Expected argument 'cron_schedule' to be a str")
        pulumi.set(__self__, "cron_schedule", cron_schedule)
        if feature_name and not isinstance(feature_name, str):
            raise TypeError("Expected argument 'feature_name' to be a str")
        pulumi.set(__self__, "feature_name", feature_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_materialization_time and not isinstance(last_materialization_time, str):
            raise TypeError("Expected argument 'last_materialization_time' to be a str")
        pulumi.set(__self__, "last_materialization_time", last_materialization_time)
        if materialized_feature_id and not isinstance(materialized_feature_id, str):
            raise TypeError("Expected argument 'materialized_feature_id' to be a str")
        pulumi.set(__self__, "materialized_feature_id", materialized_feature_id)
        if offline_store_config and not isinstance(offline_store_config, dict):
            raise TypeError("Expected argument 'offline_store_config' to be a dict")
        pulumi.set(__self__, "offline_store_config", offline_store_config)
        if online_store_config and not isinstance(online_store_config, dict):
            raise TypeError("Expected argument 'online_store_config' to be a dict")
        pulumi.set(__self__, "online_store_config", online_store_config)
        if pipeline_schedule_state and not isinstance(pipeline_schedule_state, str):
            raise TypeError("Expected argument 'pipeline_schedule_state' to be a str")
        pulumi.set(__self__, "pipeline_schedule_state", pipeline_schedule_state)
        if table_name and not isinstance(table_name, str):
            raise TypeError("Expected argument 'table_name' to be a str")
        pulumi.set(__self__, "table_name", table_name)

    @_builtins.property
    @pulumi.getter(name="cronSchedule")
    def cron_schedule(self) -> _builtins.str:
        """
        (string) - The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        """
        return pulumi.get(self, "cron_schedule")

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> _builtins.str:
        """
        (string) - The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastMaterializationTime")
    def last_materialization_time(self) -> _builtins.str:
        """
        (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
        If the pipeline has not run yet, this field will be null
        """
        return pulumi.get(self, "last_materialization_time")

    @_builtins.property
    @pulumi.getter(name="materializedFeatureId")
    def materialized_feature_id(self) -> _builtins.str:
        """
        (string) - Unique identifier for the materialized feature
        """
        return pulumi.get(self, "materialized_feature_id")

    @_builtins.property
    @pulumi.getter(name="offlineStoreConfig")
    def offline_store_config(self) -> 'outputs.GetFeatureEngineeringMaterializedFeatureOfflineStoreConfigResult':
        """
        (OfflineStoreConfig)
        """
        return pulumi.get(self, "offline_store_config")

    @_builtins.property
    @pulumi.getter(name="onlineStoreConfig")
    def online_store_config(self) -> 'outputs.GetFeatureEngineeringMaterializedFeatureOnlineStoreConfigResult':
        """
        (OnlineStoreConfig)
        """
        return pulumi.get(self, "online_store_config")

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleState")
    def pipeline_schedule_state(self) -> _builtins.str:
        """
        (string) - The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        return pulumi.get(self, "pipeline_schedule_state")

    @_builtins.property
    @pulumi.getter(name="tableName")
    def table_name(self) -> _builtins.str:
        """
        (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        return pulumi.get(self, "table_name")


class AwaitableGetFeatureEngineeringMaterializedFeatureResult(GetFeatureEngineeringMaterializedFeatureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringMaterializedFeatureResult(
            cron_schedule=self.cron_schedule,
            feature_name=self.feature_name,
            id=self.id,
            last_materialization_time=self.last_materialization_time,
            materialized_feature_id=self.materialized_feature_id,
            offline_store_config=self.offline_store_config,
            online_store_config=self.online_store_config,
            pipeline_schedule_state=self.pipeline_schedule_state,
            table_name=self.table_name)


def get_feature_engineering_materialized_feature(materialized_feature_id: Optional[_builtins.str] = None,
                                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringMaterializedFeatureResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str materialized_feature_id: Unique identifier for the materialized feature
    """
    __args__ = dict()
    __args__['materializedFeatureId'] = materialized_feature_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringMaterializedFeature:getFeatureEngineeringMaterializedFeature', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeatureResult).value

    return AwaitableGetFeatureEngineeringMaterializedFeatureResult(
        cron_schedule=pulumi.get(__ret__, 'cron_schedule'),
        feature_name=pulumi.get(__ret__, 'feature_name'),
        id=pulumi.get(__ret__, 'id'),
        last_materialization_time=pulumi.get(__ret__, 'last_materialization_time'),
        materialized_feature_id=pulumi.get(__ret__, 'materialized_feature_id'),
        offline_store_config=pulumi.get(__ret__, 'offline_store_config'),
        online_store_config=pulumi.get(__ret__, 'online_store_config'),
        pipeline_schedule_state=pulumi.get(__ret__, 'pipeline_schedule_state'),
        table_name=pulumi.get(__ret__, 'table_name'))
def get_feature_engineering_materialized_feature_output(materialized_feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringMaterializedFeatureResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str materialized_feature_id: Unique identifier for the materialized feature
    """
    __args__ = dict()
    __args__['materializedFeatureId'] = materialized_feature_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringMaterializedFeature:getFeatureEngineeringMaterializedFeature', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeatureResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringMaterializedFeatureResult(
        cron_schedule=pulumi.get(__response__, 'cron_schedule'),
        feature_name=pulumi.get(__response__, 'feature_name'),
        id=pulumi.get(__response__, 'id'),
        last_materialization_time=pulumi.get(__response__, 'last_materialization_time'),
        materialized_feature_id=pulumi.get(__response__, 'materialized_feature_id'),
        offline_store_config=pulumi.get(__response__, 'offline_store_config'),
        online_store_config=pulumi.get(__response__, 'online_store_config'),
        pipeline_schedule_state=pulumi.get(__response__, 'pipeline_schedule_state'),
        table_name=pulumi.get(__response__, 'table_name')))
