# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetPostgresBranchesResult',
    'AwaitableGetPostgresBranchesResult',
    'get_postgres_branches',
    'get_postgres_branches_output',
]

@pulumi.output_type
class GetPostgresBranchesResult:
    """
    A collection of values returned by getPostgresBranches.
    """
    def __init__(__self__, branches=None, id=None, page_size=None, parent=None):
        if branches and not isinstance(branches, list):
            raise TypeError("Expected argument 'branches' to be a list")
        pulumi.set(__self__, "branches", branches)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)

    @_builtins.property
    @pulumi.getter
    def branches(self) -> Sequence['outputs.GetPostgresBranchesBranchResult']:
        return pulumi.get(self, "branches")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> _builtins.str:
        """
        (string) - The project containing this branch (API resource hierarchy).
        Format: projects/{project_id}
        """
        return pulumi.get(self, "parent")


class AwaitableGetPostgresBranchesResult(GetPostgresBranchesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPostgresBranchesResult(
            branches=self.branches,
            id=self.id,
            page_size=self.page_size,
            parent=self.parent)


def get_postgres_branches(page_size: Optional[_builtins.int] = None,
                          parent: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPostgresBranchesResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source lists all Postgres branches in a project.

    ## Example Usage

    ### List All Branches in a Project

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_postgres_branches(parent="projects/my-project")
    pulumi.export("branchNames", [branch.name for branch in all.branches])
    ```


    :param _builtins.int page_size: Upper bound for items returned. Cannot be negative
    :param _builtins.str parent: The Project that owns this collection of branches.
           Format: projects/{project_id}
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getPostgresBranches:getPostgresBranches', __args__, opts=opts, typ=GetPostgresBranchesResult).value

    return AwaitableGetPostgresBranchesResult(
        branches=pulumi.get(__ret__, 'branches'),
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'),
        parent=pulumi.get(__ret__, 'parent'))
def get_postgres_branches_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPostgresBranchesResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source lists all Postgres branches in a project.

    ## Example Usage

    ### List All Branches in a Project

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_postgres_branches(parent="projects/my-project")
    pulumi.export("branchNames", [branch.name for branch in all.branches])
    ```


    :param _builtins.int page_size: Upper bound for items returned. Cannot be negative
    :param _builtins.str parent: The Project that owns this collection of branches.
           Format: projects/{project_id}
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getPostgresBranches:getPostgresBranches', __args__, opts=opts, typ=GetPostgresBranchesResult)
    return __ret__.apply(lambda __response__: GetPostgresBranchesResult(
        branches=pulumi.get(__response__, 'branches'),
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size'),
        parent=pulumi.get(__response__, 'parent')))
