# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountSettingUserPreferenceV2Result',
    'AwaitableGetAccountSettingUserPreferenceV2Result',
    'get_account_setting_user_preference_v2',
    'get_account_setting_user_preference_v2_output',
]

@pulumi.output_type
class GetAccountSettingUserPreferenceV2Result:
    """
    A collection of values returned by getAccountSettingUserPreferenceV2.
    """
    def __init__(__self__, boolean_val=None, effective_boolean_val=None, effective_string_val=None, id=None, name=None, string_val=None, user_id=None):
        if boolean_val and not isinstance(boolean_val, dict):
            raise TypeError("Expected argument 'boolean_val' to be a dict")
        pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_boolean_val and not isinstance(effective_boolean_val, dict):
            raise TypeError("Expected argument 'effective_boolean_val' to be a dict")
        pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_string_val and not isinstance(effective_string_val, dict):
            raise TypeError("Expected argument 'effective_string_val' to be a dict")
        pulumi.set(__self__, "effective_string_val", effective_string_val)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if string_val and not isinstance(string_val, dict):
            raise TypeError("Expected argument 'string_val' to be a dict")
        pulumi.set(__self__, "string_val", string_val)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> 'outputs.GetAccountSettingUserPreferenceV2BooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> 'outputs.GetAccountSettingUserPreferenceV2EffectiveBooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> 'outputs.GetAccountSettingUserPreferenceV2EffectiveStringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> 'outputs.GetAccountSettingUserPreferenceV2StringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "string_val")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        (string) - User ID of the user
        """
        return pulumi.get(self, "user_id")


class AwaitableGetAccountSettingUserPreferenceV2Result(GetAccountSettingUserPreferenceV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountSettingUserPreferenceV2Result(
            boolean_val=self.boolean_val,
            effective_boolean_val=self.effective_boolean_val,
            effective_string_val=self.effective_string_val,
            id=self.id,
            name=self.name,
            string_val=self.string_val,
            user_id=self.user_id)


def get_account_setting_user_preference_v2(name: Optional[_builtins.str] = None,
                                           user_id: Optional[_builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountSettingUserPreferenceV2Result:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account user preference setting.


    :param _builtins.str name: Name of the setting
    :param _builtins.str user_id: User ID of the user
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAccountSettingUserPreferenceV2:getAccountSettingUserPreferenceV2', __args__, opts=opts, typ=GetAccountSettingUserPreferenceV2Result).value

    return AwaitableGetAccountSettingUserPreferenceV2Result(
        boolean_val=pulumi.get(__ret__, 'boolean_val'),
        effective_boolean_val=pulumi.get(__ret__, 'effective_boolean_val'),
        effective_string_val=pulumi.get(__ret__, 'effective_string_val'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        string_val=pulumi.get(__ret__, 'string_val'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_account_setting_user_preference_v2_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  user_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountSettingUserPreferenceV2Result]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account user preference setting.


    :param _builtins.str name: Name of the setting
    :param _builtins.str user_id: User ID of the user
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAccountSettingUserPreferenceV2:getAccountSettingUserPreferenceV2', __args__, opts=opts, typ=GetAccountSettingUserPreferenceV2Result)
    return __ret__.apply(lambda __response__: GetAccountSettingUserPreferenceV2Result(
        boolean_val=pulumi.get(__response__, 'boolean_val'),
        effective_boolean_val=pulumi.get(__response__, 'effective_boolean_val'),
        effective_string_val=pulumi.get(__response__, 'effective_string_val'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        string_val=pulumi.get(__response__, 'string_val'),
        user_id=pulumi.get(__response__, 'user_id')))
