# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FeatureEngineeringMaterializedFeatureArgs', 'FeatureEngineeringMaterializedFeature']

@pulumi.input_type
class FeatureEngineeringMaterializedFeatureArgs:
    def __init__(__self__, *,
                 feature_name: pulumi.Input[_builtins.str],
                 cron_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 offline_store_config: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']] = None,
                 online_store_config: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']] = None,
                 pipeline_schedule_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FeatureEngineeringMaterializedFeature resource.
        :param pulumi.Input[_builtins.str] feature_name: The full name of the feature in Unity Catalog
        :param pulumi.Input[_builtins.str] cron_schedule: The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        :param pulumi.Input[_builtins.str] pipeline_schedule_state: The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        pulumi.set(__self__, "feature_name", feature_name)
        if cron_schedule is not None:
            pulumi.set(__self__, "cron_schedule", cron_schedule)
        if offline_store_config is not None:
            pulumi.set(__self__, "offline_store_config", offline_store_config)
        if online_store_config is not None:
            pulumi.set(__self__, "online_store_config", online_store_config)
        if pipeline_schedule_state is not None:
            pulumi.set(__self__, "pipeline_schedule_state", pipeline_schedule_state)

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> pulumi.Input[_builtins.str]:
        """
        The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @feature_name.setter
    def feature_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "feature_name", value)

    @_builtins.property
    @pulumi.getter(name="cronSchedule")
    def cron_schedule(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        """
        return pulumi.get(self, "cron_schedule")

    @cron_schedule.setter
    def cron_schedule(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cron_schedule", value)

    @_builtins.property
    @pulumi.getter(name="offlineStoreConfig")
    def offline_store_config(self) -> Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']]:
        return pulumi.get(self, "offline_store_config")

    @offline_store_config.setter
    def offline_store_config(self, value: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']]):
        pulumi.set(self, "offline_store_config", value)

    @_builtins.property
    @pulumi.getter(name="onlineStoreConfig")
    def online_store_config(self) -> Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']]:
        return pulumi.get(self, "online_store_config")

    @online_store_config.setter
    def online_store_config(self, value: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']]):
        pulumi.set(self, "online_store_config", value)

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleState")
    def pipeline_schedule_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        return pulumi.get(self, "pipeline_schedule_state")

    @pipeline_schedule_state.setter
    def pipeline_schedule_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_schedule_state", value)


@pulumi.input_type
class _FeatureEngineeringMaterializedFeatureState:
    def __init__(__self__, *,
                 cron_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_name: Optional[pulumi.Input[_builtins.str]] = None,
                 last_materialization_time: Optional[pulumi.Input[_builtins.str]] = None,
                 materialized_feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                 offline_store_config: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']] = None,
                 online_store_config: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']] = None,
                 pipeline_schedule_state: Optional[pulumi.Input[_builtins.str]] = None,
                 table_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FeatureEngineeringMaterializedFeature resources.
        :param pulumi.Input[_builtins.str] cron_schedule: The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        :param pulumi.Input[_builtins.str] feature_name: The full name of the feature in Unity Catalog
        :param pulumi.Input[_builtins.str] last_materialization_time: (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
               If the pipeline has not run yet, this field will be null
        :param pulumi.Input[_builtins.str] materialized_feature_id: (string) - Unique identifier for the materialized feature
        :param pulumi.Input[_builtins.str] pipeline_schedule_state: The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        :param pulumi.Input[_builtins.str] table_name: (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        if cron_schedule is not None:
            pulumi.set(__self__, "cron_schedule", cron_schedule)
        if feature_name is not None:
            pulumi.set(__self__, "feature_name", feature_name)
        if last_materialization_time is not None:
            pulumi.set(__self__, "last_materialization_time", last_materialization_time)
        if materialized_feature_id is not None:
            pulumi.set(__self__, "materialized_feature_id", materialized_feature_id)
        if offline_store_config is not None:
            pulumi.set(__self__, "offline_store_config", offline_store_config)
        if online_store_config is not None:
            pulumi.set(__self__, "online_store_config", online_store_config)
        if pipeline_schedule_state is not None:
            pulumi.set(__self__, "pipeline_schedule_state", pipeline_schedule_state)
        if table_name is not None:
            pulumi.set(__self__, "table_name", table_name)

    @_builtins.property
    @pulumi.getter(name="cronSchedule")
    def cron_schedule(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        """
        return pulumi.get(self, "cron_schedule")

    @cron_schedule.setter
    def cron_schedule(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cron_schedule", value)

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @feature_name.setter
    def feature_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "feature_name", value)

    @_builtins.property
    @pulumi.getter(name="lastMaterializationTime")
    def last_materialization_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
        If the pipeline has not run yet, this field will be null
        """
        return pulumi.get(self, "last_materialization_time")

    @last_materialization_time.setter
    def last_materialization_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_materialization_time", value)

    @_builtins.property
    @pulumi.getter(name="materializedFeatureId")
    def materialized_feature_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Unique identifier for the materialized feature
        """
        return pulumi.get(self, "materialized_feature_id")

    @materialized_feature_id.setter
    def materialized_feature_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "materialized_feature_id", value)

    @_builtins.property
    @pulumi.getter(name="offlineStoreConfig")
    def offline_store_config(self) -> Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']]:
        return pulumi.get(self, "offline_store_config")

    @offline_store_config.setter
    def offline_store_config(self, value: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs']]):
        pulumi.set(self, "offline_store_config", value)

    @_builtins.property
    @pulumi.getter(name="onlineStoreConfig")
    def online_store_config(self) -> Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']]:
        return pulumi.get(self, "online_store_config")

    @online_store_config.setter
    def online_store_config(self, value: Optional[pulumi.Input['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs']]):
        pulumi.set(self, "online_store_config", value)

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleState")
    def pipeline_schedule_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        return pulumi.get(self, "pipeline_schedule_state")

    @pipeline_schedule_state.setter
    def pipeline_schedule_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_schedule_state", value)

    @_builtins.property
    @pulumi.getter(name="tableName")
    def table_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        return pulumi.get(self, "table_name")

    @table_name.setter
    def table_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "table_name", value)


@pulumi.type_token("databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature")
class FeatureEngineeringMaterializedFeature(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_name: Optional[pulumi.Input[_builtins.str]] = None,
                 offline_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgsDict']]] = None,
                 online_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgsDict']]] = None,
                 pipeline_schedule_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "materialized_feature_id"

          to = databricks_feature_engineering_materialized_feature.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature this "materialized_feature_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cron_schedule: The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        :param pulumi.Input[_builtins.str] feature_name: The full name of the feature in Unity Catalog
        :param pulumi.Input[_builtins.str] pipeline_schedule_state: The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FeatureEngineeringMaterializedFeatureArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "materialized_feature_id"

          to = databricks_feature_engineering_materialized_feature.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature this "materialized_feature_id"
        ```

        :param str resource_name: The name of the resource.
        :param FeatureEngineeringMaterializedFeatureArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FeatureEngineeringMaterializedFeatureArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_schedule: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_name: Optional[pulumi.Input[_builtins.str]] = None,
                 offline_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgsDict']]] = None,
                 online_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgsDict']]] = None,
                 pipeline_schedule_state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FeatureEngineeringMaterializedFeatureArgs.__new__(FeatureEngineeringMaterializedFeatureArgs)

            __props__.__dict__["cron_schedule"] = cron_schedule
            if feature_name is None and not opts.urn:
                raise TypeError("Missing required property 'feature_name'")
            __props__.__dict__["feature_name"] = feature_name
            __props__.__dict__["offline_store_config"] = offline_store_config
            __props__.__dict__["online_store_config"] = online_store_config
            __props__.__dict__["pipeline_schedule_state"] = pipeline_schedule_state
            __props__.__dict__["last_materialization_time"] = None
            __props__.__dict__["materialized_feature_id"] = None
            __props__.__dict__["table_name"] = None
        super(FeatureEngineeringMaterializedFeature, __self__).__init__(
            'databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cron_schedule: Optional[pulumi.Input[_builtins.str]] = None,
            feature_name: Optional[pulumi.Input[_builtins.str]] = None,
            last_materialization_time: Optional[pulumi.Input[_builtins.str]] = None,
            materialized_feature_id: Optional[pulumi.Input[_builtins.str]] = None,
            offline_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOfflineStoreConfigArgsDict']]] = None,
            online_store_config: Optional[pulumi.Input[Union['FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgs', 'FeatureEngineeringMaterializedFeatureOnlineStoreConfigArgsDict']]] = None,
            pipeline_schedule_state: Optional[pulumi.Input[_builtins.str]] = None,
            table_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'FeatureEngineeringMaterializedFeature':
        """
        Get an existing FeatureEngineeringMaterializedFeature resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cron_schedule: The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        :param pulumi.Input[_builtins.str] feature_name: The full name of the feature in Unity Catalog
        :param pulumi.Input[_builtins.str] last_materialization_time: (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
               If the pipeline has not run yet, this field will be null
        :param pulumi.Input[_builtins.str] materialized_feature_id: (string) - Unique identifier for the materialized feature
        :param pulumi.Input[_builtins.str] pipeline_schedule_state: The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        :param pulumi.Input[_builtins.str] table_name: (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FeatureEngineeringMaterializedFeatureState.__new__(_FeatureEngineeringMaterializedFeatureState)

        __props__.__dict__["cron_schedule"] = cron_schedule
        __props__.__dict__["feature_name"] = feature_name
        __props__.__dict__["last_materialization_time"] = last_materialization_time
        __props__.__dict__["materialized_feature_id"] = materialized_feature_id
        __props__.__dict__["offline_store_config"] = offline_store_config
        __props__.__dict__["online_store_config"] = online_store_config
        __props__.__dict__["pipeline_schedule_state"] = pipeline_schedule_state
        __props__.__dict__["table_name"] = table_name
        return FeatureEngineeringMaterializedFeature(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="cronSchedule")
    def cron_schedule(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        """
        return pulumi.get(self, "cron_schedule")

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> pulumi.Output[_builtins.str]:
        """
        The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter(name="lastMaterializationTime")
    def last_materialization_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
        If the pipeline has not run yet, this field will be null
        """
        return pulumi.get(self, "last_materialization_time")

    @_builtins.property
    @pulumi.getter(name="materializedFeatureId")
    def materialized_feature_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Unique identifier for the materialized feature
        """
        return pulumi.get(self, "materialized_feature_id")

    @_builtins.property
    @pulumi.getter(name="offlineStoreConfig")
    def offline_store_config(self) -> pulumi.Output[Optional['outputs.FeatureEngineeringMaterializedFeatureOfflineStoreConfig']]:
        return pulumi.get(self, "offline_store_config")

    @_builtins.property
    @pulumi.getter(name="onlineStoreConfig")
    def online_store_config(self) -> pulumi.Output[Optional['outputs.FeatureEngineeringMaterializedFeatureOnlineStoreConfig']]:
        return pulumi.get(self, "online_store_config")

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleState")
    def pipeline_schedule_state(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        return pulumi.get(self, "pipeline_schedule_state")

    @_builtins.property
    @pulumi.getter(name="tableName")
    def table_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        return pulumi.get(self, "table_name")

